@@ -167,7 +167,7 @@ public:
      * @param parent the parent of this QObject (can be 0 for no parent)
      *
      */
-    explicit KStartupInfo(int flags, QObject *parent = 0);
+    explicit KStartupInfo(int flags, QObject *parent = nullptr);
     /**
      * Creates an instance that will receive the startup notifications.
      *
@@ -180,9 +180,9 @@ public:
      * @deprecated since 5.0
      */
 #ifndef KWINDOWSYSTEM_NO_DEPRECATED
-    KWINDOWSYSTEM_DEPRECATED explicit KStartupInfo(bool clean_on_cantdetect, QObject *parent = 0);
+    KWINDOWSYSTEM_DEPRECATED explicit KStartupInfo(bool clean_on_cantdetect, QObject *parent = nullptr);
 #endif
-    virtual ~KStartupInfo();
+    ~KStartupInfo() override;
     /**
      * Sends given notification data about started application
      * with the given startup identification. If no notification for this identification
@@ -424,7 +424,7 @@ protected:
     /**
      *
      */
-    virtual void customEvent(QEvent *e_P);
+    void customEvent(QEvent *e_P) override;
 
 private:
     Q_PRIVATE_SLOT(d, void startups_cleanup())
